@@ -352,6 +352,19 @@ where
                                 })
                                 .filter(|e| !e.is_type_only)
                             {
+                                let orig = match orig {
+                                    ModuleExportName::Ident(ident) => ident,
+                                    ModuleExportName::Str(..) => {
+                                        unimplemented!("module string names unimplemented")
+                                    }
+                                };
+                                let exported = match exported {
+                                    Some(ModuleExportName::Ident(ident)) => Some(ident),
+                                    Some(ModuleExportName::Str(..)) => {
+                                        unimplemented!("module string names unimplemented")
+                                    }
+                                    _ => None,
+                                };
                                 let mut scope_ref_mut = self.scope.borrow_mut();
                                 let scope = &mut *scope_ref_mut;
                                 let is_import_default = orig.sym == js_word!("default");
